# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/cost_analysis/v1/cost.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(spaceone/api/cost_analysis/v1/cost.proto\x12\x1dspaceone.api.cost_analysis.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\xb0\x04\n\x11\x43reateCostRequest\x12\x15\n\roriginal_cost\x18\x01 \x01(\x01\x12\x19\n\x11original_currency\x18\x02 \x01(\t\x12\x10\n\x08usd_cost\x18\x03 \x01(\x01\x12\x16\n\x0eusage_quantity\x18\x04 \x01(\x01\x12\x10\n\x08provider\x18\x05 \x01(\t\x12\x13\n\x0bregion_code\x18\x06 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\x07 \x01(\t\x12\x0f\n\x07product\x18\x08 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\t \x01(\t\x12\x12\n\nusage_type\x18\n \x01(\t\x12\x16\n\x0eresource_group\x18\x0b \x01(\t\x12\x10\n\x08resource\x18\x0c \x01(\t\x12%\n\x04tags\x18\x15 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x30\n\x0f\x61\x64\x64itional_info\x18\x16 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x1a\n\x12service_account_id\x18\x1f \x01(\t\x12\x12\n\nproject_id\x18  \x01(\t\x12\x16\n\x0e\x64\x61ta_source_id\x18! \x01(\t\x12\x11\n\tdomain_id\x18\" \x01(\t\x12\x11\n\tbilled_at\x18) \x01(\t\x12\x14\n\x0cproduct_code\x18* \x01(\t\x12\x1d\n\x15original_product_code\x18+ \x01(\t\x12\x13\n\x0bproduct_sku\x18, \x01(\t\x12\x15\n\rexchange_rate\x18- \x01(\x01\"1\n\x0b\x43ostRequest\x12\x0f\n\x07\x63ost_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"B\n\x0eGetCostRequest\x12\x0f\n\x07\x63ost_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xb5\x03\n\tCostQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x0f\n\x07\x63ost_id\x18\x02 \x01(\t\x12\x19\n\x11original_currency\x18\x03 \x01(\t\x12\x10\n\x08provider\x18\x04 \x01(\t\x12\x13\n\x0bregion_code\x18\x05 \x01(\t\x12\x12\n\nregion_key\x18\x06 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\x07 \x01(\t\x12\x0f\n\x07product\x18\x08 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\t \x01(\t\x12\x12\n\nusage_type\x18\n \x01(\t\x12\x16\n\x0eresource_group\x18\x0b \x01(\t\x12\x10\n\x08resource\x18\x0c \x01(\t\x12\x1a\n\x12service_account_id\x18\x15 \x01(\t\x12\x12\n\nproject_id\x18\x16 \x01(\t\x12\x16\n\x0e\x64\x61ta_source_id\x18\x17 \x01(\t\x12\x11\n\tdomain_id\x18\x18 \x01(\t\x12\x14\n\x0cproduct_code\x18\x19 \x01(\t\x12\x1d\n\x15original_product_code\x18\x1a \x01(\t\x12\x13\n\x0bproduct_sku\x18\x1b \x01(\t\"\xf3\x04\n\x08\x43ostInfo\x12\x0f\n\x07\x63ost_id\x18\x01 \x01(\t\x12\x10\n\x08usd_cost\x18\x02 \x01(\x01\x12\x19\n\x11original_currency\x18\x03 \x01(\t\x12\x15\n\roriginal_cost\x18\x04 \x01(\x01\x12\x16\n\x0eusage_quantity\x18\x05 \x01(\x01\x12\x10\n\x08provider\x18\x06 \x01(\t\x12\x13\n\x0bregion_code\x18\x07 \x01(\t\x12\x12\n\nregion_key\x18\x08 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\t \x01(\t\x12\x0f\n\x07product\x18\n \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x0b \x01(\t\x12\x12\n\nusage_type\x18\x0c \x01(\t\x12\x16\n\x0eresource_group\x18\r \x01(\t\x12\x10\n\x08resource\x18\x0e \x01(\t\x12%\n\x04tags\x18\x15 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x30\n\x0f\x61\x64\x64itional_info\x18\x16 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x1a\n\x12service_account_id\x18\x1f \x01(\t\x12\x12\n\nproject_id\x18  \x01(\t\x12\x16\n\x0e\x64\x61ta_source_id\x18! \x01(\t\x12\x11\n\tdomain_id\x18\" \x01(\t\x12\x11\n\tbilled_at\x18) \x01(\t\x12\x12\n\ncreated_at\x18* \x01(\t\x12\x11\n\tcost_type\x18+ \x01(\t\x12\x14\n\x0cproduct_code\x18, \x01(\t\x12\x1d\n\x15original_product_code\x18- \x01(\t\x12\x13\n\x0bproduct_sku\x18. \x01(\t\x12\x15\n\rexchange_rate\x18/ \x01(\x01\"Z\n\tCostsInfo\x12\x38\n\x07results\x18\x01 \x03(\x0b\x32\'.spaceone.api.cost_analysis.v1.CostInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"\xcc\x03\n\x10\x43ostAnalyzeQuery\x12P\n\x0bgranularity\x18\x01 \x01(\x0e\x32;.spaceone.api.cost_analysis.v1.CostAnalyzeQuery.Granularity\x12\r\n\x05start\x18\x02 \x01(\t\x12\x0b\n\x03\x65nd\x18\x03 \x01(\t\x12\x10\n\x08group_by\x18\x04 \x03(\t\x12*\n\x06\x66ilter\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\r\n\x05limit\x18\x06 \x01(\x05\x12(\n\x04page\x18\x07 \x01(\x0b\x32\x1a.spaceone.api.core.v1.Page\x12(\n\x04sort\x18\x08 \x01(\x0b\x32\x1a.spaceone.api.core.v1.Sort\x12\x1e\n\x16include_usage_quantity\x18\t \x01(\x08\x12\x16\n\x0einclude_others\x18\n \x01(\x08\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"^\n\x0bGranularity\x12\r\n\tUNIT_NONE\x10\x00\x12\x0f\n\x0b\x41\x43\x43UMULATED\x10\x01\x12\t\n\x05\x44\x41ILY\x10\x02\x12\x0b\n\x07MONTHLY\x10\x03\x12\n\n\x06YEARLY\x10\x04\x12\x0b\n\x07INVOICE\x10\x05\"X\n\rCostStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xa0\x08\n\x04\x43ost\x12\x84\x01\n\x06\x63reate\x12\x30.spaceone.api.cost_analysis.v1.CreateCostRequest\x1a\'.spaceone.api.cost_analysis.v1.CostInfo\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x17/cost-analysis/v1/costs\x12v\n\x06\x64\x65lete\x12*.spaceone.api.cost_analysis.v1.CostRequest\x1a\x16.google.protobuf.Empty\"(\x82\xd3\xe4\x93\x02\"* /cost-analysis/v1/cost/{cost_id}\x12\x87\x01\n\x03get\x12-.spaceone.api.cost_analysis.v1.GetCostRequest\x1a\'.spaceone.api.cost_analysis.v1.CostInfo\"(\x82\xd3\xe4\x93\x02\"\x12 /cost-analysis/v1/cost/{cost_id}\x12\x9d\x01\n\x04list\x12(.spaceone.api.cost_analysis.v1.CostQuery\x1a(.spaceone.api.cost_analysis.v1.CostsInfo\"A\x82\xd3\xe4\x93\x02;\x12\x17/cost-analysis/v1/costsZ \"\x1e/cost-analysis/v1/costs/search\x12|\n\x07\x61nalyze\x12/.spaceone.api.cost_analysis.v1.CostAnalyzeQuery\x1a\x17.google.protobuf.Struct\"\'\x82\xd3\xe4\x93\x02!\"\x1f/cost-analysis/v1/costs/analyze\x12s\n\x04stat\x12,.spaceone.api.cost_analysis.v1.CostStatQuery\x1a\x17.google.protobuf.Struct\"$\x82\xd3\xe4\x93\x02\x1e\"\x1c/cost-analysis/v1/costs/stat\x12~\n\x08invoices\x12/.spaceone.api.cost_analysis.v1.CostAnalyzeQuery\x1a\x17.google.protobuf.Struct\"(\x82\xd3\xe4\x93\x02\"\" /cost-analysis/v1/costs/invoices\x12|\n\x07invoice\x12/.spaceone.api.cost_analysis.v1.CostAnalyzeQuery\x1a\x17.google.protobuf.Struct\"\'\x82\xd3\xe4\x93\x02!\"\x1f/cost-analysis/v1/costs/invoiceb\x06proto3')



_CREATECOSTREQUEST = DESCRIPTOR.message_types_by_name['CreateCostRequest']
_COSTREQUEST = DESCRIPTOR.message_types_by_name['CostRequest']
_GETCOSTREQUEST = DESCRIPTOR.message_types_by_name['GetCostRequest']
_COSTQUERY = DESCRIPTOR.message_types_by_name['CostQuery']
_COSTINFO = DESCRIPTOR.message_types_by_name['CostInfo']
_COSTSINFO = DESCRIPTOR.message_types_by_name['CostsInfo']
_COSTANALYZEQUERY = DESCRIPTOR.message_types_by_name['CostAnalyzeQuery']
_COSTSTATQUERY = DESCRIPTOR.message_types_by_name['CostStatQuery']
_COSTANALYZEQUERY_GRANULARITY = _COSTANALYZEQUERY.enum_types_by_name['Granularity']
CreateCostRequest = _reflection.GeneratedProtocolMessageType('CreateCostRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECOSTREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.CreateCostRequest)
  })
_sym_db.RegisterMessage(CreateCostRequest)

CostRequest = _reflection.GeneratedProtocolMessageType('CostRequest', (_message.Message,), {
  'DESCRIPTOR' : _COSTREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.CostRequest)
  })
_sym_db.RegisterMessage(CostRequest)

GetCostRequest = _reflection.GeneratedProtocolMessageType('GetCostRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCOSTREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.GetCostRequest)
  })
_sym_db.RegisterMessage(GetCostRequest)

CostQuery = _reflection.GeneratedProtocolMessageType('CostQuery', (_message.Message,), {
  'DESCRIPTOR' : _COSTQUERY,
  '__module__' : 'spaceone.api.cost_analysis.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.CostQuery)
  })
_sym_db.RegisterMessage(CostQuery)

CostInfo = _reflection.GeneratedProtocolMessageType('CostInfo', (_message.Message,), {
  'DESCRIPTOR' : _COSTINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.CostInfo)
  })
_sym_db.RegisterMessage(CostInfo)

CostsInfo = _reflection.GeneratedProtocolMessageType('CostsInfo', (_message.Message,), {
  'DESCRIPTOR' : _COSTSINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.CostsInfo)
  })
_sym_db.RegisterMessage(CostsInfo)

CostAnalyzeQuery = _reflection.GeneratedProtocolMessageType('CostAnalyzeQuery', (_message.Message,), {
  'DESCRIPTOR' : _COSTANALYZEQUERY,
  '__module__' : 'spaceone.api.cost_analysis.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.CostAnalyzeQuery)
  })
_sym_db.RegisterMessage(CostAnalyzeQuery)

CostStatQuery = _reflection.GeneratedProtocolMessageType('CostStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _COSTSTATQUERY,
  '__module__' : 'spaceone.api.cost_analysis.v1.cost_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.CostStatQuery)
  })
_sym_db.RegisterMessage(CostStatQuery)

_COST = DESCRIPTOR.services_by_name['Cost']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COST.methods_by_name['create']._options = None
  _COST.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\031\"\027/cost-analysis/v1/costs'
  _COST.methods_by_name['delete']._options = None
  _COST.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002\"* /cost-analysis/v1/cost/{cost_id}'
  _COST.methods_by_name['get']._options = None
  _COST.methods_by_name['get']._serialized_options = b'\202\323\344\223\002\"\022 /cost-analysis/v1/cost/{cost_id}'
  _COST.methods_by_name['list']._options = None
  _COST.methods_by_name['list']._serialized_options = b'\202\323\344\223\002;\022\027/cost-analysis/v1/costsZ \"\036/cost-analysis/v1/costs/search'
  _COST.methods_by_name['analyze']._options = None
  _COST.methods_by_name['analyze']._serialized_options = b'\202\323\344\223\002!\"\037/cost-analysis/v1/costs/analyze'
  _COST.methods_by_name['stat']._options = None
  _COST.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\036\"\034/cost-analysis/v1/costs/stat'
  _COST.methods_by_name['invoices']._options = None
  _COST.methods_by_name['invoices']._serialized_options = b'\202\323\344\223\002\"\" /cost-analysis/v1/costs/invoices'
  _COST.methods_by_name['invoice']._options = None
  _COST.methods_by_name['invoice']._serialized_options = b'\202\323\344\223\002!\"\037/cost-analysis/v1/costs/invoice'
  _CREATECOSTREQUEST._serialized_start=199
  _CREATECOSTREQUEST._serialized_end=759
  _COSTREQUEST._serialized_start=761
  _COSTREQUEST._serialized_end=810
  _GETCOSTREQUEST._serialized_start=812
  _GETCOSTREQUEST._serialized_end=878
  _COSTQUERY._serialized_start=881
  _COSTQUERY._serialized_end=1318
  _COSTINFO._serialized_start=1321
  _COSTINFO._serialized_end=1948
  _COSTSINFO._serialized_start=1950
  _COSTSINFO._serialized_end=2040
  _COSTANALYZEQUERY._serialized_start=2043
  _COSTANALYZEQUERY._serialized_end=2503
  _COSTANALYZEQUERY_GRANULARITY._serialized_start=2409
  _COSTANALYZEQUERY_GRANULARITY._serialized_end=2503
  _COSTSTATQUERY._serialized_start=2505
  _COSTSTATQUERY._serialized_end=2593
  _COST._serialized_start=2596
  _COST._serialized_end=3652
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.statistics.v1 import history_pb2 as spaceone_dot_api_dot_statistics_dot_v1_dot_history__pb2


class HistoryStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/spaceone.api.statistics.v1.History/create',
                request_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_history__pb2.CreateHistoryRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.statistics.v1.History/list',
                request_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_history__pb2.QueryHistoryRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_history__pb2.HistoryInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.statistics.v1.History/stat',
                request_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_history__pb2.HistoryStatRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class HistoryServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        desc: Creates a new History. Gets a Schedule as an input and creates a History as an output. You can use this method to manually run a specific Schedule.
        request_example: >-
        {
        "schedule_id": "sch-b1d8be347bed",
        "domain_id": "domain-58010aa2e451"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        desc: Gets a list of all Histories. You can use a query to get a filtered list of Histories.
        request_example: >-
        {
        "query": {},
        "domain_id": "domain-58010aa2e451"
        }
        response_example: >-
        {
        "results": [
        {
        "topic": "daily_cloud_service_summary",
        "values": {
        "label": "Storage",
        "project_id": "project-f7111a9aa0c6",
        "provider": "azure",
        "value": 32213303296.0,
        "cloud_service_group": "Compute",
        "cloud_service_type": "Disk"
        },
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-07-18T01:01:57.579Z"
        },
        {
        "topic": "daily_cloud_service_summary",
        "values": {
        "cloud_service_type": "Bucket",
        "cloud_service_group": "CloudStorage",
        "label": "Storage",
        "provider": "google_cloud",
        "project_id": "project-4cd006b4993b",
        "value": 401399880.0
        },
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-07-18T01:01:57.579Z"
        }
        ],
        "total_count": 2
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_HistoryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_history__pb2.CreateHistoryRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_history__pb2.QueryHistoryRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_history__pb2.HistoryInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_history__pb2.HistoryStatRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.statistics.v1.History', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class History(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.statistics.v1.History/create',
            spaceone_dot_api_dot_statistics_dot_v1_dot_history__pb2.CreateHistoryRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.statistics.v1.History/list',
            spaceone_dot_api_dot_statistics_dot_v1_dot_history__pb2.QueryHistoryRequest.SerializeToString,
            spaceone_dot_api_dot_statistics_dot_v1_dot_history__pb2.HistoryInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.statistics.v1.History/stat',
            spaceone_dot_api_dot_statistics_dot_v1_dot_history__pb2.HistoryStatRequest.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/inventory/v1/resource_setting.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0spaceone/api/inventory/v1/resource_setting.proto\x12\x19spaceone.api.inventory.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"}\n\x16ResourceSettingRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x10\n\x08provider\x18\x02 \x01(\t\x12\x12\n\nsetting_id\x18\x03 \x01(\t\x12*\n\x05query\x18\x04 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\"a\n\tCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x0e\n\x06use_yn\x18\x02 \x01(\t\x12\x0e\n\x06parser\x18\x03 \x01(\t\x12\r\n\x05value\x18\x04 \x01(\t\x12\x10\n\x08operator\x18\x05 \x01(\t\"z\n\x06Unused\x12\x0f\n\x07service\x18\x01 \x01(\t\x12\x16\n\x0esub_title_name\x18\x02 \x01(\t\x12\x0e\n\x06use_yn\x18\x03 \x01(\t\x12\x37\n\tcondition\x18\x04 \x03(\x0b\x32$.spaceone.api.inventory.v1.Condition\"\xde\x02\n\x13ResourceSettingInfo\x12\x12\n\nsetting_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x10\n\x08provider\x18\x03 \x01(\t\x12\x14\n\x0c\x64isplay_type\x18\x04 \x01(\t\x12\x1f\n\x17\x64\x65signed_component_name\x18\x05 \x01(\t\x12\x11\n\ttab_title\x18\x06 \x01(\t\x12\x14\n\x0csetting_type\x18\x07 \x01(\t\x12\x12\n\ncreated_at\x18\x08 \x01(\t\x12\x12\n\nupdated_at\x18\t \x01(\t\x12%\n\x04tags\x18\n \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x31\n\x06unused\x18\x0b \x03(\x0b\x32!.spaceone.api.inventory.v1.Unused\x12,\n\x0brightsizing\x18\x0c \x01(\x0b\x32\x17.google.protobuf.Struct\"h\n\x17ResourceSettingListInfo\x12M\n\x15resource_setting_info\x18\x01 \x03(\x0b\x32..spaceone.api.inventory.v1.ResourceSettingInfo\"d\n\x0bTagListInfo\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x10\n\x08provider\x18\x02 \x01(\t\x12\x30\n\x04tags\x18\x03 \x03(\x0b\x32\".spaceone.api.inventory.v1.TagList\")\n\x07TagList\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x11\n\tvalueList\x18\x02 \x03(\t2\xaf\x07\n\x0fResourceSetting\x12\x9a\x01\n\x04list\x12\x31.spaceone.api.inventory.v1.ResourceSettingRequest\x1a\x32.spaceone.api.inventory.v1.ResourceSettingListInfo\"+\x82\xd3\xe4\x93\x02%\"#/inventory/v1/resource-setting/list\x12\x94\x01\n\x03get\x12\x31.spaceone.api.inventory.v1.ResourceSettingRequest\x1a..spaceone.api.inventory.v1.ResourceSettingInfo\"*\x82\xd3\xe4\x93\x02$\"\"/inventory/v1/resource-setting/get\x12\x97\x01\n\x06\x63reate\x12..spaceone.api.inventory.v1.ResourceSettingInfo\x1a..spaceone.api.inventory.v1.ResourceSettingInfo\"-\x82\xd3\xe4\x93\x02\'\"%/inventory/v1/resource-setting/create\x12\x97\x01\n\x06update\x12..spaceone.api.inventory.v1.ResourceSettingInfo\x1a..spaceone.api.inventory.v1.ResourceSettingInfo\"-\x82\xd3\xe4\x93\x02\'\"%/inventory/v1/resource-setting/update\x12\x9a\x01\n\x06\x64\x65lete\x12\x31.spaceone.api.inventory.v1.ResourceSettingRequest\x1a..spaceone.api.inventory.v1.ResourceSettingInfo\"-\x82\xd3\xe4\x93\x02\'\"%/inventory/v1/resource-setting/delete\x12\x96\x01\n\x08tag_list\x12\x31.spaceone.api.inventory.v1.ResourceSettingRequest\x1a&.spaceone.api.inventory.v1.TagListInfo\"/\x82\xd3\xe4\x93\x02)\"\'/inventory/v1/resource-setting/tag/listb\x06proto3')



_RESOURCESETTINGREQUEST = DESCRIPTOR.message_types_by_name['ResourceSettingRequest']
_CONDITION = DESCRIPTOR.message_types_by_name['Condition']
_UNUSED = DESCRIPTOR.message_types_by_name['Unused']
_RESOURCESETTINGINFO = DESCRIPTOR.message_types_by_name['ResourceSettingInfo']
_RESOURCESETTINGLISTINFO = DESCRIPTOR.message_types_by_name['ResourceSettingListInfo']
_TAGLISTINFO = DESCRIPTOR.message_types_by_name['TagListInfo']
_TAGLIST = DESCRIPTOR.message_types_by_name['TagList']
ResourceSettingRequest = _reflection.GeneratedProtocolMessageType('ResourceSettingRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCESETTINGREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.resource_setting_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ResourceSettingRequest)
  })
_sym_db.RegisterMessage(ResourceSettingRequest)

Condition = _reflection.GeneratedProtocolMessageType('Condition', (_message.Message,), {
  'DESCRIPTOR' : _CONDITION,
  '__module__' : 'spaceone.api.inventory.v1.resource_setting_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.Condition)
  })
_sym_db.RegisterMessage(Condition)

Unused = _reflection.GeneratedProtocolMessageType('Unused', (_message.Message,), {
  'DESCRIPTOR' : _UNUSED,
  '__module__' : 'spaceone.api.inventory.v1.resource_setting_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.Unused)
  })
_sym_db.RegisterMessage(Unused)

ResourceSettingInfo = _reflection.GeneratedProtocolMessageType('ResourceSettingInfo', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCESETTINGINFO,
  '__module__' : 'spaceone.api.inventory.v1.resource_setting_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ResourceSettingInfo)
  })
_sym_db.RegisterMessage(ResourceSettingInfo)

ResourceSettingListInfo = _reflection.GeneratedProtocolMessageType('ResourceSettingListInfo', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCESETTINGLISTINFO,
  '__module__' : 'spaceone.api.inventory.v1.resource_setting_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ResourceSettingListInfo)
  })
_sym_db.RegisterMessage(ResourceSettingListInfo)

TagListInfo = _reflection.GeneratedProtocolMessageType('TagListInfo', (_message.Message,), {
  'DESCRIPTOR' : _TAGLISTINFO,
  '__module__' : 'spaceone.api.inventory.v1.resource_setting_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.TagListInfo)
  })
_sym_db.RegisterMessage(TagListInfo)

TagList = _reflection.GeneratedProtocolMessageType('TagList', (_message.Message,), {
  'DESCRIPTOR' : _TAGLIST,
  '__module__' : 'spaceone.api.inventory.v1.resource_setting_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.TagList)
  })
_sym_db.RegisterMessage(TagList)

_RESOURCESETTING = DESCRIPTOR.services_by_name['ResourceSetting']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RESOURCESETTING.methods_by_name['list']._options = None
  _RESOURCESETTING.methods_by_name['list']._serialized_options = b'\202\323\344\223\002%\"#/inventory/v1/resource-setting/list'
  _RESOURCESETTING.methods_by_name['get']._options = None
  _RESOURCESETTING.methods_by_name['get']._serialized_options = b'\202\323\344\223\002$\"\"/inventory/v1/resource-setting/get'
  _RESOURCESETTING.methods_by_name['create']._options = None
  _RESOURCESETTING.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\'\"%/inventory/v1/resource-setting/create'
  _RESOURCESETTING.methods_by_name['update']._options = None
  _RESOURCESETTING.methods_by_name['update']._serialized_options = b'\202\323\344\223\002\'\"%/inventory/v1/resource-setting/update'
  _RESOURCESETTING.methods_by_name['delete']._options = None
  _RESOURCESETTING.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002\'\"%/inventory/v1/resource-setting/delete'
  _RESOURCESETTING.methods_by_name['tag_list']._options = None
  _RESOURCESETTING.methods_by_name['tag_list']._serialized_options = b'\202\323\344\223\002)\"\'/inventory/v1/resource-setting/tag/list'
  _RESOURCESETTINGREQUEST._serialized_start=202
  _RESOURCESETTINGREQUEST._serialized_end=327
  _CONDITION._serialized_start=329
  _CONDITION._serialized_end=426
  _UNUSED._serialized_start=428
  _UNUSED._serialized_end=550
  _RESOURCESETTINGINFO._serialized_start=553
  _RESOURCESETTINGINFO._serialized_end=903
  _RESOURCESETTINGLISTINFO._serialized_start=905
  _RESOURCESETTINGLISTINFO._serialized_end=1009
  _TAGLISTINFO._serialized_start=1011
  _TAGLISTINFO._serialized_end=1111
  _TAGLIST._serialized_start=1113
  _TAGLIST._serialized_end=1154
  _RESOURCESETTING._serialized_start=1157
  _RESOURCESETTING._serialized_end=2100
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/identity/v1/role.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#spaceone/api/identity/v1/role.proto\x12\x18spaceone.api.identity.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\x96\x01\n\nRolePolicy\x12\x44\n\x0bpolicy_type\x18\x01 \x01(\x0e\x32/.spaceone.api.identity.v1.RolePolicy.PolicyType\x12\x11\n\tpolicy_id\x18\x02 \x01(\t\"/\n\nPolicyType\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07MANAGED\x10\x01\x12\n\n\x06\x43USTOM\x10\x02\"\x95\x01\n\x0ePagePermission\x12\x0c\n\x04page\x18\x01 \x01(\t\x12G\n\npermission\x18\x02 \x01(\x0e\x32\x33.spaceone.api.identity.v1.PagePermission.Permission\",\n\nPermission\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04VIEW\x10\x01\x12\n\n\x06MANAGE\x10\x02\"\x8e\x02\n\x11\x43reateRoleRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x35\n\trole_type\x18\x02 \x01(\x0e\x32\".spaceone.api.identity.v1.RoleType\x12\x36\n\x08policies\x18\x03 \x03(\x0b\x32$.spaceone.api.identity.v1.RolePolicy\x12\x42\n\x10page_permissions\x18\x04 \x03(\x0b\x32(.spaceone.api.identity.v1.PagePermission\x12%\n\x04tags\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x06 \x01(\t\"\x8a\x02\n\x11UpdateRoleRequest\x12\x0f\n\x07role_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x36\n\x08policies\x18\x03 \x03(\x0b\x32$.spaceone.api.identity.v1.RolePolicy\x12\x42\n\x10page_permissions\x18\x04 \x03(\x0b\x32(.spaceone.api.identity.v1.PagePermission\x12%\n\x04tags\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12 \n\x18release_page_permissions\x18\x06 \x01(\x08\x12\x11\n\tdomain_id\x18\x07 \x01(\t\"1\n\x0bRoleRequest\x12\x0f\n\x07role_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"B\n\x0eGetRoleRequest\x12\x0f\n\x07role_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xbe\x02\n\x08RoleInfo\x12\x0f\n\x07role_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x35\n\trole_type\x18\x03 \x01(\x0e\x32\".spaceone.api.identity.v1.RoleType\x12\x36\n\x08policies\x18\x04 \x03(\x0b\x32$.spaceone.api.identity.v1.RolePolicy\x12\x42\n\x10page_permissions\x18\x05 \x03(\x0b\x32(.spaceone.api.identity.v1.PagePermission\x12%\n\x04tags\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\x12\x12\n\ncreated_at\x18\x15 \x01(\t\x12\x12\n\ndeleted_at\x18\x16 \x01(\t\"\xb3\x01\n\tRoleQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x0f\n\x07role_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x35\n\trole_type\x18\x05 \x01(\x0e\x32\".spaceone.api.identity.v1.RoleType\x12\x11\n\tpolicy_id\x18\x06 \x01(\t\x12\x11\n\tdomain_id\x18\x07 \x01(\t\"U\n\tRolesInfo\x12\x33\n\x07results\x18\x01 \x03(\x0b\x32\".spaceone.api.identity.v1.RoleInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"X\n\rRoleStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t*9\n\x08RoleType\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06SYSTEM\x10\x01\x12\n\n\x06\x44OMAIN\x10\x02\x12\x0b\n\x07PROJECT\x10\x03\x32\xdf\x05\n\x04Role\x12u\n\x06\x63reate\x12+.spaceone.api.identity.v1.CreateRoleRequest\x1a\".spaceone.api.identity.v1.RoleInfo\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x12/identity/v1/roles\x12\x7f\n\x06update\x12+.spaceone.api.identity.v1.UpdateRoleRequest\x1a\".spaceone.api.identity.v1.RoleInfo\"$\x82\xd3\xe4\x93\x02\x1e\x1a\x1c/identity/v1/roles/{role_id}\x12m\n\x06\x64\x65lete\x12%.spaceone.api.identity.v1.RoleRequest\x1a\x16.google.protobuf.Empty\"$\x82\xd3\xe4\x93\x02\x1e*\x1c/identity/v1/roles/{role_id}\x12y\n\x03get\x12(.spaceone.api.identity.v1.GetRoleRequest\x1a\".spaceone.api.identity.v1.RoleInfo\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/identity/v1/roles/{role_id}\x12\x89\x01\n\x04list\x12#.spaceone.api.identity.v1.RoleQuery\x1a#.spaceone.api.identity.v1.RolesInfo\"7\x82\xd3\xe4\x93\x02\x31\x12\x12/identity/v1/rolesZ\x1b\"\x19/identity/v1/roles/search\x12i\n\x04stat\x12\'.spaceone.api.identity.v1.RoleStatQuery\x1a\x17.google.protobuf.Struct\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x17/identity/v1/roles/statb\x06proto3')

_ROLETYPE = DESCRIPTOR.enum_types_by_name['RoleType']
RoleType = enum_type_wrapper.EnumTypeWrapper(_ROLETYPE)
NONE = 0
SYSTEM = 1
DOMAIN = 2
PROJECT = 3


_ROLEPOLICY = DESCRIPTOR.message_types_by_name['RolePolicy']
_PAGEPERMISSION = DESCRIPTOR.message_types_by_name['PagePermission']
_CREATEROLEREQUEST = DESCRIPTOR.message_types_by_name['CreateRoleRequest']
_UPDATEROLEREQUEST = DESCRIPTOR.message_types_by_name['UpdateRoleRequest']
_ROLEREQUEST = DESCRIPTOR.message_types_by_name['RoleRequest']
_GETROLEREQUEST = DESCRIPTOR.message_types_by_name['GetRoleRequest']
_ROLEINFO = DESCRIPTOR.message_types_by_name['RoleInfo']
_ROLEQUERY = DESCRIPTOR.message_types_by_name['RoleQuery']
_ROLESINFO = DESCRIPTOR.message_types_by_name['RolesInfo']
_ROLESTATQUERY = DESCRIPTOR.message_types_by_name['RoleStatQuery']
_ROLEPOLICY_POLICYTYPE = _ROLEPOLICY.enum_types_by_name['PolicyType']
_PAGEPERMISSION_PERMISSION = _PAGEPERMISSION.enum_types_by_name['Permission']
RolePolicy = _reflection.GeneratedProtocolMessageType('RolePolicy', (_message.Message,), {
  'DESCRIPTOR' : _ROLEPOLICY,
  '__module__' : 'spaceone.api.identity.v1.role_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.RolePolicy)
  })
_sym_db.RegisterMessage(RolePolicy)

PagePermission = _reflection.GeneratedProtocolMessageType('PagePermission', (_message.Message,), {
  'DESCRIPTOR' : _PAGEPERMISSION,
  '__module__' : 'spaceone.api.identity.v1.role_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.PagePermission)
  })
_sym_db.RegisterMessage(PagePermission)

CreateRoleRequest = _reflection.GeneratedProtocolMessageType('CreateRoleRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEROLEREQUEST,
  '__module__' : 'spaceone.api.identity.v1.role_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.CreateRoleRequest)
  })
_sym_db.RegisterMessage(CreateRoleRequest)

UpdateRoleRequest = _reflection.GeneratedProtocolMessageType('UpdateRoleRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEROLEREQUEST,
  '__module__' : 'spaceone.api.identity.v1.role_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.UpdateRoleRequest)
  })
_sym_db.RegisterMessage(UpdateRoleRequest)

RoleRequest = _reflection.GeneratedProtocolMessageType('RoleRequest', (_message.Message,), {
  'DESCRIPTOR' : _ROLEREQUEST,
  '__module__' : 'spaceone.api.identity.v1.role_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.RoleRequest)
  })
_sym_db.RegisterMessage(RoleRequest)

GetRoleRequest = _reflection.GeneratedProtocolMessageType('GetRoleRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETROLEREQUEST,
  '__module__' : 'spaceone.api.identity.v1.role_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.GetRoleRequest)
  })
_sym_db.RegisterMessage(GetRoleRequest)

RoleInfo = _reflection.GeneratedProtocolMessageType('RoleInfo', (_message.Message,), {
  'DESCRIPTOR' : _ROLEINFO,
  '__module__' : 'spaceone.api.identity.v1.role_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.RoleInfo)
  })
_sym_db.RegisterMessage(RoleInfo)

RoleQuery = _reflection.GeneratedProtocolMessageType('RoleQuery', (_message.Message,), {
  'DESCRIPTOR' : _ROLEQUERY,
  '__module__' : 'spaceone.api.identity.v1.role_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.RoleQuery)
  })
_sym_db.RegisterMessage(RoleQuery)

RolesInfo = _reflection.GeneratedProtocolMessageType('RolesInfo', (_message.Message,), {
  'DESCRIPTOR' : _ROLESINFO,
  '__module__' : 'spaceone.api.identity.v1.role_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.RolesInfo)
  })
_sym_db.RegisterMessage(RolesInfo)

RoleStatQuery = _reflection.GeneratedProtocolMessageType('RoleStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _ROLESTATQUERY,
  '__module__' : 'spaceone.api.identity.v1.role_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.RoleStatQuery)
  })
_sym_db.RegisterMessage(RoleStatQuery)

_ROLE = DESCRIPTOR.services_by_name['Role']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ROLE.methods_by_name['create']._options = None
  _ROLE.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\024\"\022/identity/v1/roles'
  _ROLE.methods_by_name['update']._options = None
  _ROLE.methods_by_name['update']._serialized_options = b'\202\323\344\223\002\036\032\034/identity/v1/roles/{role_id}'
  _ROLE.methods_by_name['delete']._options = None
  _ROLE.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002\036*\034/identity/v1/roles/{role_id}'
  _ROLE.methods_by_name['get']._options = None
  _ROLE.methods_by_name['get']._serialized_options = b'\202\323\344\223\002\036\022\034/identity/v1/roles/{role_id}'
  _ROLE.methods_by_name['list']._options = None
  _ROLE.methods_by_name['list']._serialized_options = b'\202\323\344\223\0021\022\022/identity/v1/rolesZ\033\"\031/identity/v1/roles/search'
  _ROLE.methods_by_name['stat']._options = None
  _ROLE.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\031\"\027/identity/v1/roles/stat'
  _ROLETYPE._serialized_start=1834
  _ROLETYPE._serialized_end=1891
  _ROLEPOLICY._serialized_start=189
  _ROLEPOLICY._serialized_end=339
  _ROLEPOLICY_POLICYTYPE._serialized_start=292
  _ROLEPOLICY_POLICYTYPE._serialized_end=339
  _PAGEPERMISSION._serialized_start=342
  _PAGEPERMISSION._serialized_end=491
  _PAGEPERMISSION_PERMISSION._serialized_start=447
  _PAGEPERMISSION_PERMISSION._serialized_end=491
  _CREATEROLEREQUEST._serialized_start=494
  _CREATEROLEREQUEST._serialized_end=764
  _UPDATEROLEREQUEST._serialized_start=767
  _UPDATEROLEREQUEST._serialized_end=1033
  _ROLEREQUEST._serialized_start=1035
  _ROLEREQUEST._serialized_end=1084
  _GETROLEREQUEST._serialized_start=1086
  _GETROLEREQUEST._serialized_end=1152
  _ROLEINFO._serialized_start=1155
  _ROLEINFO._serialized_end=1473
  _ROLEQUERY._serialized_start=1476
  _ROLEQUERY._serialized_end=1655
  _ROLESINFO._serialized_start=1657
  _ROLESINFO._serialized_end=1742
  _ROLESTATQUERY._serialized_start=1744
  _ROLESTATQUERY._serialized_end=1832
  _ROLE._serialized_start=1894
  _ROLE._serialized_end=2629
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/file_manager/v1/file.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'spaceone/api/file_manager/v1/file.proto\x12\x1cspaceone.api.file_manager.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\";\n\rFileReference\x12\x15\n\rresource_type\x18\x01 \x01(\t\x12\x13\n\x0bresource_id\x18\x02 \x01(\t\"\xeb\x01\n\x11\x43reateFileRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12%\n\x04tags\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12>\n\treference\x18\x03 \x01(\x0b\x32+.spaceone.api.file_manager.v1.FileReference\x12\x11\n\tdomain_id\x18\x0b \x01(\t\x12\x15\n\rfile_src_type\x18\r \x01(\t\x12\x11\n\tfile_size\x18\x0e \x01(\t\x12\x11\n\tfile_path\x18\x0f \x01(\t\x12\x11\n\tlink_name\x18\x10 \x01(\t\"\xee\x01\n\x11UpdateFileRequest\x12\x0f\n\x07\x66ile_id\x18\x01 \x01(\t\x12%\n\x04tags\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12>\n\treference\x18\x03 \x01(\x0b\x32+.spaceone.api.file_manager.v1.FileReference\x12\x11\n\tdomain_id\x18\x0b \x01(\t\x12\x15\n\rfile_src_type\x18\r \x01(\t\x12\x11\n\tfile_size\x18\x0e \x01(\t\x12\x11\n\tfile_path\x18\x0f \x01(\t\x12\x11\n\tlink_name\x18\x10 \x01(\t\"1\n\x0b\x46ileRequest\x12\x0f\n\x07\x66ile_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"B\n\x0eGetFileRequest\x12\x0f\n\x07\x66ile_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\x80\x03\n\tFileQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x0f\n\x07\x66ile_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x36\n\x05state\x18\x04 \x01(\x0e\x32\'.spaceone.api.file_manager.v1.FileState\x12\x36\n\x05scope\x18\x05 \x01(\x0e\x32\'.spaceone.api.file_manager.v1.FileScope\x12\x11\n\tfile_type\x18\x06 \x01(\t\x12\x15\n\rresource_type\x18\x07 \x01(\t\x12\x13\n\x0bresource_id\x18\x08 \x01(\t\x12\x16\n\x0euser_domain_id\x18\x0b \x01(\t\x12\x11\n\tdomain_id\x18\x0c \x01(\t\x12\x15\n\rfile_src_type\x18\r \x01(\t\x12\x11\n\tfile_size\x18\x0e \x01(\t\x12\x11\n\tfile_path\x18\x0f \x01(\t\x12\x11\n\tlink_name\x18\x10 \x01(\t\"\x8e\x04\n\x08\x46ileInfo\x12\x0f\n\x07\x66ile_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x36\n\x05state\x18\x03 \x01(\x0e\x32\'.spaceone.api.file_manager.v1.FileState\x12\x36\n\x05scope\x18\x04 \x01(\x0e\x32\'.spaceone.api.file_manager.v1.FileScope\x12\x11\n\tfile_type\x18\x05 \x01(\t\x12\x12\n\nupload_url\x18\x06 \x01(\t\x12/\n\x0eupload_options\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x14\n\x0c\x64ownload_url\x18\x08 \x01(\t\x12%\n\x04tags\x18\t \x01(\x0b\x32\x17.google.protobuf.Struct\x12>\n\treference\x18\n \x01(\x0b\x32+.spaceone.api.file_manager.v1.FileReference\x12\x0f\n\x07user_id\x18\x0b \x01(\t\x12\x16\n\x0euser_domain_id\x18\x0c \x01(\t\x12\x11\n\tdomain_id\x18\r \x01(\t\x12\x15\n\rfile_src_type\x18\x0e \x01(\t\x12\x11\n\tfile_size\x18\x0f \x01(\t\x12\x11\n\tfile_path\x18\x10 \x01(\t\x12\x11\n\tlink_name\x18\x11 \x01(\t\x12\x12\n\ncreated_at\x18\x15 \x01(\t\"Y\n\tFilesInfo\x12\x37\n\x07results\x18\x01 \x03(\x0b\x32&.spaceone.api.file_manager.v1.FileInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"X\n\rFileStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t*2\n\tFileState\x12\x0e\n\nSTATE_NONE\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x08\n\x04\x44ONE\x10\x02*3\n\tFileScope\x12\x0e\n\nSCOPE_NONE\x10\x00\x12\n\n\x06PUBLIC\x10\x01\x12\n\n\x06\x44OMAIN\x10\x02\x32\xbd\x07\n\x04\x46ile\x12~\n\x03\x61\x64\x64\x12/.spaceone.api.file_manager.v1.CreateFileRequest\x1a&.spaceone.api.file_manager.v1.FileInfo\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x16/file-manager/v1/files\x12\x8a\x01\n\x06update\x12/.spaceone.api.file_manager.v1.UpdateFileRequest\x1a&.spaceone.api.file_manager.v1.FileInfo\"\'\x82\xd3\xe4\x93\x02!\x1a\x1f/file-manager/v1/file/{file_id}\x12t\n\x06\x64\x65lete\x12).spaceone.api.file_manager.v1.FileRequest\x1a\x16.google.protobuf.Empty\"\'\x82\xd3\xe4\x93\x02!*\x1f/file-manager/v1/file/{file_id}\x12\x9b\x01\n\x10get_download_url\x12).spaceone.api.file_manager.v1.FileRequest\x1a&.spaceone.api.file_manager.v1.FileInfo\"4\x82\xd3\xe4\x93\x02.\x12,/file-manager/v1/file/{file_id}/download-url\x12\x84\x01\n\x03get\x12,.spaceone.api.file_manager.v1.GetFileRequest\x1a&.spaceone.api.file_manager.v1.FileInfo\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/file-manager/v1/file/{file_id}\x12\x99\x01\n\x04list\x12\'.spaceone.api.file_manager.v1.FileQuery\x1a\'.spaceone.api.file_manager.v1.FilesInfo\"?\x82\xd3\xe4\x93\x02\x39\x12\x16/file-manager/v1/filesZ\x1f\"\x1d/file-manager/v1/files/search\x12q\n\x04stat\x12+.spaceone.api.file_manager.v1.FileStatQuery\x1a\x17.google.protobuf.Struct\"#\x82\xd3\xe4\x93\x02\x1d\"\x1b/file-manager/v1/files/statb\x06proto3')

_FILESTATE = DESCRIPTOR.enum_types_by_name['FileState']
FileState = enum_type_wrapper.EnumTypeWrapper(_FILESTATE)
_FILESCOPE = DESCRIPTOR.enum_types_by_name['FileScope']
FileScope = enum_type_wrapper.EnumTypeWrapper(_FILESCOPE)
STATE_NONE = 0
PENDING = 1
DONE = 2
SCOPE_NONE = 0
PUBLIC = 1
DOMAIN = 2


_FILEREFERENCE = DESCRIPTOR.message_types_by_name['FileReference']
_CREATEFILEREQUEST = DESCRIPTOR.message_types_by_name['CreateFileRequest']
_UPDATEFILEREQUEST = DESCRIPTOR.message_types_by_name['UpdateFileRequest']
_FILEREQUEST = DESCRIPTOR.message_types_by_name['FileRequest']
_GETFILEREQUEST = DESCRIPTOR.message_types_by_name['GetFileRequest']
_FILEQUERY = DESCRIPTOR.message_types_by_name['FileQuery']
_FILEINFO = DESCRIPTOR.message_types_by_name['FileInfo']
_FILESINFO = DESCRIPTOR.message_types_by_name['FilesInfo']
_FILESTATQUERY = DESCRIPTOR.message_types_by_name['FileStatQuery']
FileReference = _reflection.GeneratedProtocolMessageType('FileReference', (_message.Message,), {
  'DESCRIPTOR' : _FILEREFERENCE,
  '__module__' : 'spaceone.api.file_manager.v1.file_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.file_manager.v1.FileReference)
  })
_sym_db.RegisterMessage(FileReference)

CreateFileRequest = _reflection.GeneratedProtocolMessageType('CreateFileRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFILEREQUEST,
  '__module__' : 'spaceone.api.file_manager.v1.file_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.file_manager.v1.CreateFileRequest)
  })
_sym_db.RegisterMessage(CreateFileRequest)

UpdateFileRequest = _reflection.GeneratedProtocolMessageType('UpdateFileRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFILEREQUEST,
  '__module__' : 'spaceone.api.file_manager.v1.file_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.file_manager.v1.UpdateFileRequest)
  })
_sym_db.RegisterMessage(UpdateFileRequest)

FileRequest = _reflection.GeneratedProtocolMessageType('FileRequest', (_message.Message,), {
  'DESCRIPTOR' : _FILEREQUEST,
  '__module__' : 'spaceone.api.file_manager.v1.file_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.file_manager.v1.FileRequest)
  })
_sym_db.RegisterMessage(FileRequest)

GetFileRequest = _reflection.GeneratedProtocolMessageType('GetFileRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFILEREQUEST,
  '__module__' : 'spaceone.api.file_manager.v1.file_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.file_manager.v1.GetFileRequest)
  })
_sym_db.RegisterMessage(GetFileRequest)

FileQuery = _reflection.GeneratedProtocolMessageType('FileQuery', (_message.Message,), {
  'DESCRIPTOR' : _FILEQUERY,
  '__module__' : 'spaceone.api.file_manager.v1.file_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.file_manager.v1.FileQuery)
  })
_sym_db.RegisterMessage(FileQuery)

FileInfo = _reflection.GeneratedProtocolMessageType('FileInfo', (_message.Message,), {
  'DESCRIPTOR' : _FILEINFO,
  '__module__' : 'spaceone.api.file_manager.v1.file_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.file_manager.v1.FileInfo)
  })
_sym_db.RegisterMessage(FileInfo)

FilesInfo = _reflection.GeneratedProtocolMessageType('FilesInfo', (_message.Message,), {
  'DESCRIPTOR' : _FILESINFO,
  '__module__' : 'spaceone.api.file_manager.v1.file_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.file_manager.v1.FilesInfo)
  })
_sym_db.RegisterMessage(FilesInfo)

FileStatQuery = _reflection.GeneratedProtocolMessageType('FileStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _FILESTATQUERY,
  '__module__' : 'spaceone.api.file_manager.v1.file_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.file_manager.v1.FileStatQuery)
  })
_sym_db.RegisterMessage(FileStatQuery)

_FILE = DESCRIPTOR.services_by_name['File']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FILE.methods_by_name['add']._options = None
  _FILE.methods_by_name['add']._serialized_options = b'\202\323\344\223\002\030\"\026/file-manager/v1/files'
  _FILE.methods_by_name['update']._options = None
  _FILE.methods_by_name['update']._serialized_options = b'\202\323\344\223\002!\032\037/file-manager/v1/file/{file_id}'
  _FILE.methods_by_name['delete']._options = None
  _FILE.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002!*\037/file-manager/v1/file/{file_id}'
  _FILE.methods_by_name['get_download_url']._options = None
  _FILE.methods_by_name['get_download_url']._serialized_options = b'\202\323\344\223\002.\022,/file-manager/v1/file/{file_id}/download-url'
  _FILE.methods_by_name['get']._options = None
  _FILE.methods_by_name['get']._serialized_options = b'\202\323\344\223\002!\022\037/file-manager/v1/file/{file_id}'
  _FILE.methods_by_name['list']._options = None
  _FILE.methods_by_name['list']._serialized_options = b'\202\323\344\223\0029\022\026/file-manager/v1/filesZ\037\"\035/file-manager/v1/files/search'
  _FILE.methods_by_name['stat']._options = None
  _FILE.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\035\"\033/file-manager/v1/files/stat'
  _FILESTATE._serialized_start=1952
  _FILESTATE._serialized_end=2002
  _FILESCOPE._serialized_start=2004
  _FILESCOPE._serialized_end=2055
  _FILEREFERENCE._serialized_start=196
  _FILEREFERENCE._serialized_end=255
  _CREATEFILEREQUEST._serialized_start=258
  _CREATEFILEREQUEST._serialized_end=493
  _UPDATEFILEREQUEST._serialized_start=496
  _UPDATEFILEREQUEST._serialized_end=734
  _FILEREQUEST._serialized_start=736
  _FILEREQUEST._serialized_end=785
  _GETFILEREQUEST._serialized_start=787
  _GETFILEREQUEST._serialized_end=853
  _FILEQUERY._serialized_start=856
  _FILEQUERY._serialized_end=1240
  _FILEINFO._serialized_start=1243
  _FILEINFO._serialized_end=1769
  _FILESINFO._serialized_start=1771
  _FILESINFO._serialized_end=1860
  _FILESTATQUERY._serialized_start=1862
  _FILESTATQUERY._serialized_end=1950
  _FILE._serialized_start=2058
  _FILE._serialized_end=3015
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/secret/v1/trusted_secret.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+spaceone/api/secret/v1/trusted_secret.proto\x12\x16spaceone.api.secret.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\xb7\x01\n\x1a\x43reateTrustedSecretRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12%\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x04tags\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06schema\x18\x04 \x01(\t\x12\x1a\n\x12service_account_id\x18\x05 \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"\x7f\n\x1aUpdateTrustedSecretRequest\x12\x19\n\x11trusted_secret_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12%\n\x04tags\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"D\n\x14TrustedSecretRequest\x12\x19\n\x11trusted_secret_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"\x85\x01\n\x1eUpdateTrustedSecretDataRequest\x12\x19\n\x11trusted_secret_id\x18\x01 \x01(\t\x12%\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06schema\x18\x03 \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"U\n\x17GetTrustedSecretRequest\x12\x19\n\x11trusted_secret_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xba\x01\n\x12TrustedSecretQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x19\n\x11trusted_secret_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0e\n\x06schema\x18\x06 \x01(\t\x12\x10\n\x08provider\x18\x07 \x01(\t\x12\x1a\n\x12service_account_id\x18\t \x01(\t\x12\x11\n\tdomain_id\x18\x15 \x01(\t\"\xdc\x01\n\x11TrustedSecretInfo\x12\x19\n\x11trusted_secret_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12%\n\x04tags\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06schema\x18\x04 \x01(\t\x12\x10\n\x08provider\x18\x05 \x01(\t\x12\x1a\n\x12service_account_id\x18\x06 \x01(\t\x12\x12\n\nproject_id\x18\x07 \x01(\t\x12\x11\n\tdomain_id\x18\x15 \x01(\t\x12\x12\n\ncreated_at\x18\x16 \x01(\t\"e\n\x12TrustedSecretsInfo\x12:\n\x07results\x18\x01 \x03(\x0b\x32).spaceone.api.secret.v1.TrustedSecretInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"a\n\x16TrustedSecretStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xa1\x08\n\rTrustedSecret\x12\x8b\x01\n\x06\x63reate\x12\x32.spaceone.api.secret.v1.CreateTrustedSecretRequest\x1a).spaceone.api.secret.v1.TrustedSecretInfo\"\"\x82\xd3\xe4\x93\x02\x1c\"\x1a/secret/v1/trusted-secrets\x12\x9e\x01\n\x06update\x12\x32.spaceone.api.secret.v1.UpdateTrustedSecretRequest\x1a).spaceone.api.secret.v1.TrustedSecretInfo\"5\x82\xd3\xe4\x93\x02/\x1a-/secret/v1/trusted-secret/{trusted_secret_id}\x12\x85\x01\n\x06\x64\x65lete\x12,.spaceone.api.secret.v1.TrustedSecretRequest\x1a\x16.google.protobuf.Empty\"5\x82\xd3\xe4\x93\x02/*-/secret/v1/trusted-secret/{trusted_secret_id}\x12\x99\x01\n\x0bupdate_data\x12\x36.spaceone.api.secret.v1.UpdateTrustedSecretDataRequest\x1a\x16.google.protobuf.Empty\":\x82\xd3\xe4\x93\x02\x34\x1a\x32/secret/v1/trusted-secret/{trusted_secret_id}/data\x12\x98\x01\n\x03get\x12/.spaceone.api.secret.v1.GetTrustedSecretRequest\x1a).spaceone.api.secret.v1.TrustedSecretInfo\"5\x82\xd3\xe4\x93\x02/\x12-/secret/v1/trusted-secret/{trusted_secret_id}\x12\xa7\x01\n\x04list\x12*.spaceone.api.secret.v1.TrustedSecretQuery\x1a*.spaceone.api.secret.v1.TrustedSecretsInfo\"G\x82\xd3\xe4\x93\x02\x41\x12\x1a/secret/v1/trusted-secretsZ#\"!/secret/v1/trusted-secrets/search\x12x\n\x04stat\x12..spaceone.api.secret.v1.TrustedSecretStatQuery\x1a\x17.google.protobuf.Struct\"\'\x82\xd3\xe4\x93\x02!\"\x1f/secret/v1/trusted-secrets/statb\x06proto3')



_CREATETRUSTEDSECRETREQUEST = DESCRIPTOR.message_types_by_name['CreateTrustedSecretRequest']
_UPDATETRUSTEDSECRETREQUEST = DESCRIPTOR.message_types_by_name['UpdateTrustedSecretRequest']
_TRUSTEDSECRETREQUEST = DESCRIPTOR.message_types_by_name['TrustedSecretRequest']
_UPDATETRUSTEDSECRETDATAREQUEST = DESCRIPTOR.message_types_by_name['UpdateTrustedSecretDataRequest']
_GETTRUSTEDSECRETREQUEST = DESCRIPTOR.message_types_by_name['GetTrustedSecretRequest']
_TRUSTEDSECRETQUERY = DESCRIPTOR.message_types_by_name['TrustedSecretQuery']
_TRUSTEDSECRETINFO = DESCRIPTOR.message_types_by_name['TrustedSecretInfo']
_TRUSTEDSECRETSINFO = DESCRIPTOR.message_types_by_name['TrustedSecretsInfo']
_TRUSTEDSECRETSTATQUERY = DESCRIPTOR.message_types_by_name['TrustedSecretStatQuery']
CreateTrustedSecretRequest = _reflection.GeneratedProtocolMessageType('CreateTrustedSecretRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATETRUSTEDSECRETREQUEST,
  '__module__' : 'spaceone.api.secret.v1.trusted_secret_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.secret.v1.CreateTrustedSecretRequest)
  })
_sym_db.RegisterMessage(CreateTrustedSecretRequest)

UpdateTrustedSecretRequest = _reflection.GeneratedProtocolMessageType('UpdateTrustedSecretRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATETRUSTEDSECRETREQUEST,
  '__module__' : 'spaceone.api.secret.v1.trusted_secret_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.secret.v1.UpdateTrustedSecretRequest)
  })
_sym_db.RegisterMessage(UpdateTrustedSecretRequest)

TrustedSecretRequest = _reflection.GeneratedProtocolMessageType('TrustedSecretRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRUSTEDSECRETREQUEST,
  '__module__' : 'spaceone.api.secret.v1.trusted_secret_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.secret.v1.TrustedSecretRequest)
  })
_sym_db.RegisterMessage(TrustedSecretRequest)

UpdateTrustedSecretDataRequest = _reflection.GeneratedProtocolMessageType('UpdateTrustedSecretDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATETRUSTEDSECRETDATAREQUEST,
  '__module__' : 'spaceone.api.secret.v1.trusted_secret_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.secret.v1.UpdateTrustedSecretDataRequest)
  })
_sym_db.RegisterMessage(UpdateTrustedSecretDataRequest)

GetTrustedSecretRequest = _reflection.GeneratedProtocolMessageType('GetTrustedSecretRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTRUSTEDSECRETREQUEST,
  '__module__' : 'spaceone.api.secret.v1.trusted_secret_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.secret.v1.GetTrustedSecretRequest)
  })
_sym_db.RegisterMessage(GetTrustedSecretRequest)

TrustedSecretQuery = _reflection.GeneratedProtocolMessageType('TrustedSecretQuery', (_message.Message,), {
  'DESCRIPTOR' : _TRUSTEDSECRETQUERY,
  '__module__' : 'spaceone.api.secret.v1.trusted_secret_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.secret.v1.TrustedSecretQuery)
  })
_sym_db.RegisterMessage(TrustedSecretQuery)

TrustedSecretInfo = _reflection.GeneratedProtocolMessageType('TrustedSecretInfo', (_message.Message,), {
  'DESCRIPTOR' : _TRUSTEDSECRETINFO,
  '__module__' : 'spaceone.api.secret.v1.trusted_secret_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.secret.v1.TrustedSecretInfo)
  })
_sym_db.RegisterMessage(TrustedSecretInfo)

TrustedSecretsInfo = _reflection.GeneratedProtocolMessageType('TrustedSecretsInfo', (_message.Message,), {
  'DESCRIPTOR' : _TRUSTEDSECRETSINFO,
  '__module__' : 'spaceone.api.secret.v1.trusted_secret_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.secret.v1.TrustedSecretsInfo)
  })
_sym_db.RegisterMessage(TrustedSecretsInfo)

TrustedSecretStatQuery = _reflection.GeneratedProtocolMessageType('TrustedSecretStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _TRUSTEDSECRETSTATQUERY,
  '__module__' : 'spaceone.api.secret.v1.trusted_secret_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.secret.v1.TrustedSecretStatQuery)
  })
_sym_db.RegisterMessage(TrustedSecretStatQuery)

_TRUSTEDSECRET = DESCRIPTOR.services_by_name['TrustedSecret']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TRUSTEDSECRET.methods_by_name['create']._options = None
  _TRUSTEDSECRET.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\034\"\032/secret/v1/trusted-secrets'
  _TRUSTEDSECRET.methods_by_name['update']._options = None
  _TRUSTEDSECRET.methods_by_name['update']._serialized_options = b'\202\323\344\223\002/\032-/secret/v1/trusted-secret/{trusted_secret_id}'
  _TRUSTEDSECRET.methods_by_name['delete']._options = None
  _TRUSTEDSECRET.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002/*-/secret/v1/trusted-secret/{trusted_secret_id}'
  _TRUSTEDSECRET.methods_by_name['update_data']._options = None
  _TRUSTEDSECRET.methods_by_name['update_data']._serialized_options = b'\202\323\344\223\0024\0322/secret/v1/trusted-secret/{trusted_secret_id}/data'
  _TRUSTEDSECRET.methods_by_name['get']._options = None
  _TRUSTEDSECRET.methods_by_name['get']._serialized_options = b'\202\323\344\223\002/\022-/secret/v1/trusted-secret/{trusted_secret_id}'
  _TRUSTEDSECRET.methods_by_name['list']._options = None
  _TRUSTEDSECRET.methods_by_name['list']._serialized_options = b'\202\323\344\223\002A\022\032/secret/v1/trusted-secretsZ#\"!/secret/v1/trusted-secrets/search'
  _TRUSTEDSECRET.methods_by_name['stat']._options = None
  _TRUSTEDSECRET.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002!\"\037/secret/v1/trusted-secrets/stat'
  _CREATETRUSTEDSECRETREQUEST._serialized_start=195
  _CREATETRUSTEDSECRETREQUEST._serialized_end=378
  _UPDATETRUSTEDSECRETREQUEST._serialized_start=380
  _UPDATETRUSTEDSECRETREQUEST._serialized_end=507
  _TRUSTEDSECRETREQUEST._serialized_start=509
  _TRUSTEDSECRETREQUEST._serialized_end=577
  _UPDATETRUSTEDSECRETDATAREQUEST._serialized_start=580
  _UPDATETRUSTEDSECRETDATAREQUEST._serialized_end=713
  _GETTRUSTEDSECRETREQUEST._serialized_start=715
  _GETTRUSTEDSECRETREQUEST._serialized_end=800
  _TRUSTEDSECRETQUERY._serialized_start=803
  _TRUSTEDSECRETQUERY._serialized_end=989
  _TRUSTEDSECRETINFO._serialized_start=992
  _TRUSTEDSECRETINFO._serialized_end=1212
  _TRUSTEDSECRETSINFO._serialized_start=1214
  _TRUSTEDSECRETSINFO._serialized_end=1315
  _TRUSTEDSECRETSTATQUERY._serialized_start=1317
  _TRUSTEDSECRETSTATQUERY._serialized_end=1414
  _TRUSTEDSECRET._serialized_start=1417
  _TRUSTEDSECRET._serialized_end=2474
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/provisioning/v1/catalog_resource_history.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;spaceone/api/provisioning/v1/catalog_resource_history.proto\x12\x1cspaceone.api.provisioning.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\xa5\x03\n\x1b\x43\x61talogResourceHistoryQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12#\n\x1b\x63\x61talog_resource_history_id\x18\x03 \x01(\t\x12\x1a\n\x12\x63\x61talog_history_id\x18\x04 \x01(\t\x12\x1b\n\x13\x63\x61talog_resource_id\x18\x05 \x01(\t\x12\x15\n\rresource_name\x18\x06 \x01(\t\x12P\n\x06\x61\x63tion\x18\x07 \x01(\x0e\x32@.spaceone.api.provisioning.v1.CatalogResourceHistoryQuery.Action\x12\x12\n\ncreated_at\x18\x08 \x01(\t\x12\x0c\n\x04type\x18\t \x01(\t\x12\x12\n\ncatalog_id\x18\n \x01(\t\x12\x12\n\ncreated_by\x18\x0b \x01(\t\"6\n\x06\x41\x63tion\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06\x43REATE\x10\x01\x12\n\n\x06UPDATE\x10\x02\x12\n\n\x06\x44\x45LETE\x10\x03\"\xb5\x03\n\x1a\x43\x61talogResourceHistoryInfo\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12#\n\x1b\x63\x61talog_resource_history_id\x18\x02 \x01(\t\x12\x1a\n\x12\x63\x61talog_history_id\x18\x03 \x01(\t\x12\x1b\n\x13\x63\x61talog_resource_id\x18\x04 \x01(\t\x12\x15\n\rresource_name\x18\x05 \x01(\t\x12O\n\x06\x61\x63tion\x18\x06 \x01(\x0e\x32?.spaceone.api.provisioning.v1.CatalogResourceHistoryInfo.Action\x12(\n\x04\x64iff\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x12\n\ndiff_count\x18\x08 \x01(\x05\x12\x12\n\ncreated_at\x18\t \x01(\t\x12\x0c\n\x04type\x18\n \x01(\t\x12\x12\n\ncatalog_id\x18\x0b \x01(\t\x12\x12\n\ncreated_by\x18\x0c \x01(\t\"6\n\x06\x41\x63tion\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06\x43REATE\x10\x01\x12\n\n\x06UPDATE\x10\x02\x12\n\n\x06\x44\x45LETE\x10\x03\"~\n\x1c\x43\x61talogResourceHistoriesInfo\x12I\n\x07results\x18\x01 \x03(\x0b\x32\x38.spaceone.api.provisioning.v1.CatalogResourceHistoryInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"\x9b\x01\n\x1f\x43\x61talogResourceHistoryStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x1b\n\x13\x63\x61talog_resource_id\x18\x03 \x01(\t\x12\x12\n\ncatalog_id\x18\x04 \x01(\t2\xa9\x05\n\x16\x43\x61talogResourceHistory\x12\x96\x02\n\x1eget_catalog_resource_histories\x12\x39.spaceone.api.provisioning.v1.CatalogResourceHistoryQuery\x1a:.spaceone.api.provisioning.v1.CatalogResourceHistoriesInfo\"}\x82\xd3\xe4\x93\x02w\x12\x41/provisioning/v1/catalog-resource/{catalog_resource_id}/historiesZ2\"0/provisioning/v1/catalog-resource-history/search\x12\xdc\x01\n\x1cget_catalog_resource_history\x12\x39.spaceone.api.provisioning.v1.CatalogResourceHistoryQuery\x1a\x38.spaceone.api.provisioning.v1.CatalogResourceHistoryInfo\"G\x82\xd3\xe4\x93\x02\x41\"?/provisioning/v1/catalog-resource/{catalog_resource_id}/history\x12\x96\x01\n\x04stat\x12=.spaceone.api.provisioning.v1.CatalogResourceHistoryStatQuery\x1a\x17.google.protobuf.Struct\"6\x82\xd3\xe4\x93\x02\x30\"./provisioning/v1/catalog-resource-history/statb\x06proto3')



_CATALOGRESOURCEHISTORYQUERY = DESCRIPTOR.message_types_by_name['CatalogResourceHistoryQuery']
_CATALOGRESOURCEHISTORYINFO = DESCRIPTOR.message_types_by_name['CatalogResourceHistoryInfo']
_CATALOGRESOURCEHISTORIESINFO = DESCRIPTOR.message_types_by_name['CatalogResourceHistoriesInfo']
_CATALOGRESOURCEHISTORYSTATQUERY = DESCRIPTOR.message_types_by_name['CatalogResourceHistoryStatQuery']
_CATALOGRESOURCEHISTORYQUERY_ACTION = _CATALOGRESOURCEHISTORYQUERY.enum_types_by_name['Action']
_CATALOGRESOURCEHISTORYINFO_ACTION = _CATALOGRESOURCEHISTORYINFO.enum_types_by_name['Action']
CatalogResourceHistoryQuery = _reflection.GeneratedProtocolMessageType('CatalogResourceHistoryQuery', (_message.Message,), {
  'DESCRIPTOR' : _CATALOGRESOURCEHISTORYQUERY,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_resource_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CatalogResourceHistoryQuery)
  })
_sym_db.RegisterMessage(CatalogResourceHistoryQuery)

CatalogResourceHistoryInfo = _reflection.GeneratedProtocolMessageType('CatalogResourceHistoryInfo', (_message.Message,), {
  'DESCRIPTOR' : _CATALOGRESOURCEHISTORYINFO,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_resource_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CatalogResourceHistoryInfo)
  })
_sym_db.RegisterMessage(CatalogResourceHistoryInfo)

CatalogResourceHistoriesInfo = _reflection.GeneratedProtocolMessageType('CatalogResourceHistoriesInfo', (_message.Message,), {
  'DESCRIPTOR' : _CATALOGRESOURCEHISTORIESINFO,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_resource_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CatalogResourceHistoriesInfo)
  })
_sym_db.RegisterMessage(CatalogResourceHistoriesInfo)

CatalogResourceHistoryStatQuery = _reflection.GeneratedProtocolMessageType('CatalogResourceHistoryStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _CATALOGRESOURCEHISTORYSTATQUERY,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_resource_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CatalogResourceHistoryStatQuery)
  })
_sym_db.RegisterMessage(CatalogResourceHistoryStatQuery)

_CATALOGRESOURCEHISTORY = DESCRIPTOR.services_by_name['CatalogResourceHistory']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CATALOGRESOURCEHISTORY.methods_by_name['get_catalog_resource_histories']._options = None
  _CATALOGRESOURCEHISTORY.methods_by_name['get_catalog_resource_histories']._serialized_options = b'\202\323\344\223\002w\022A/provisioning/v1/catalog-resource/{catalog_resource_id}/historiesZ2\"0/provisioning/v1/catalog-resource-history/search'
  _CATALOGRESOURCEHISTORY.methods_by_name['get_catalog_resource_history']._options = None
  _CATALOGRESOURCEHISTORY.methods_by_name['get_catalog_resource_history']._serialized_options = b'\202\323\344\223\002A\"?/provisioning/v1/catalog-resource/{catalog_resource_id}/history'
  _CATALOGRESOURCEHISTORY.methods_by_name['stat']._options = None
  _CATALOGRESOURCEHISTORY.methods_by_name['stat']._serialized_options = b'\202\323\344\223\0020\"./provisioning/v1/catalog-resource-history/stat'
  _CATALOGRESOURCEHISTORYQUERY._serialized_start=188
  _CATALOGRESOURCEHISTORYQUERY._serialized_end=609
  _CATALOGRESOURCEHISTORYQUERY_ACTION._serialized_start=555
  _CATALOGRESOURCEHISTORYQUERY_ACTION._serialized_end=609
  _CATALOGRESOURCEHISTORYINFO._serialized_start=612
  _CATALOGRESOURCEHISTORYINFO._serialized_end=1049
  _CATALOGRESOURCEHISTORYINFO_ACTION._serialized_start=555
  _CATALOGRESOURCEHISTORYINFO_ACTION._serialized_end=609
  _CATALOGRESOURCEHISTORIESINFO._serialized_start=1051
  _CATALOGRESOURCEHISTORIESINFO._serialized_end=1177
  _CATALOGRESOURCEHISTORYSTATQUERY._serialized_start=1180
  _CATALOGRESOURCEHISTORYSTATQUERY._serialized_end=1335
  _CATALOGRESOURCEHISTORY._serialized_start=1338
  _CATALOGRESOURCEHISTORY._serialized_end=2019
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.monitoring.v1 import event_rule_pb2 as spaceone_dot_api_dot_monitoring_dot_v1_dot_event__rule__pb2


class EventRuleStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/spaceone.api.monitoring.v1.EventRule/create',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_event__rule__pb2.CreateEventRuleRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_event__rule__pb2.EventRuleInfo.FromString,
                )
        self.update = channel.unary_unary(
                '/spaceone.api.monitoring.v1.EventRule/update',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_event__rule__pb2.UpdateEventRuleRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_event__rule__pb2.EventRuleInfo.FromString,
                )
        self.change_order = channel.unary_unary(
                '/spaceone.api.monitoring.v1.EventRule/change_order',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_event__rule__pb2.ChangeEventRuleOrderRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_event__rule__pb2.EventRuleInfo.FromString,
                )
        self.delete = channel.unary_unary(
                '/spaceone.api.monitoring.v1.EventRule/delete',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_event__rule__pb2.EventRuleRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.get = channel.unary_unary(
                '/spaceone.api.monitoring.v1.EventRule/get',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_event__rule__pb2.GetEventRuleRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_event__rule__pb2.EventRuleInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.monitoring.v1.EventRule/list',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_event__rule__pb2.EventRuleQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_event__rule__pb2.EventRulesInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.monitoring.v1.EventRule/stat',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_event__rule__pb2.EventRuleStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class EventRuleServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        desc: Creates a new EventRule. You can filter the Events to apply the EventRule by setting the input parameter `Conditions`. The method can change the Events' assignee or Project.
        request_example: >-
        {
        "conditions": [{"key": "description", "value": "API", "operator": "contain"}],
        "conditions_policy": "ALL",
        "actions": {"change_assignee": "user1@email.com",
        "change_urgency": "LOW",
        "change_project": "project-123456789012",
        "add_additional_info": {"type": "personal rule"},
        "no_notification": true},
        "options": {},
        "project_id": "project-123456789012",
        "domain_id": "domain-123456789012"
        }
        response_example: >-
        {
        "event_rule_id": "er-123456789012",
        "order": 1,
        "conditions": [
        {
        "key": "description",
        "value": "API",
        "operator": "contain"
        }
        ],
        "conditions_policy": "ALL",
        "actions": {
        "change_assignee": "user1@email.com",
        "change_urgency": "LOW",
        "change_project": "project-123456789012",
        "add_additional_info": {
        "type": "personal rule"
        },
        "no_notification": true
        },
        "options": {},
        "scope": "PROJECT",
        "project_id": "project-123456789012",
        "tags": {},
        "domain_id": "domain-123456789012",
        "created_at": "2022-01-02T06:02:31.517Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """
        desc: Changes a priority order between EventRules to apply. EventRules are filtered by the order configured.
        request_example: >-
        {
        "event_rule_id": "er-123456789012",
        "conditions": [{"key": "description", "value": "ELB", "operator": "contain"}],
        "conditions_policy": "ALL",
        "actions": {"change_assignee": "user2@email.com",
        "change_urgency": "HIGH",
        "change_project": "project-123456789012",
        "add_additional_info": {"type": "personal rule"},
        "no_notification": true},
        "options": {},
        "domain_id": "domain-123456789012"
        }
        response_example: >-
        {
        "event_rule_id": "er-123456789012",
        "order": 2,
        "conditions": [
        {
        "key": "description",
        "value": "ELB",
        "operator": "contain"
        }
        ],
        "conditions_policy": "ALL",
        "actions": {
        "change_assignee": "user2@email.com",
        "change_urgency": "HIGH",
        "change_project": "project-123456789012",
        "add_additional_info": {
        "type": "personal rule"
        },
        "no_notification": true
        },
        "options": {},
        "scope": "PROJECT",
        "project_id": "project-123456789012",
        "tags": {},
        "domain_id": "domain-123456789012",
        "created_at": "2022-01-01T06:02:31.517Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def change_order(self, request, context):
        """
        desc: Updates a specific EventRule. You can make changes in EventRule settings.
        request_example: >-
        {
        "event_rule_id": "er-123456789012",
        "order": 2,
        "domain_id": "domain-123456789012"
        }
        response_example: >-
        {
        "event_rule_id": "er-123456789012",
        "order": 2,
        "conditions": [
        {
        "key": "description",
        "value": "API",
        "operator": "contain"
        }
        ],
        "conditions_policy": "ALL",
        "actions": {
        "change_assignee": "user1@email.com",
        "change_urgency": "LOW",
        "change_project": "project-123456789012",
        "add_additional_info": {
        "type": "personal rule"
        },
        "no_notification": true
        },
        "options": {},
        "scope": "PROJECT",
        "project_id": "project-123456789012",
        "tags": {},
        "domain_id": "domain-123456789012",
        "created_at": "2022-01-02T06:02:31.517Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """
        desc: Deletes a specific EventRule. You must assign an EventRule resource to delete by specifying `event_rule_id`.
        request_example: >-
        {
        "event_rule_id": "er-123456789012",
        "domain_id": "domain-123456789012"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        desc: Gets a specific EventRule. Prints detailed information about the EventRule.
        request_example: >-
        {
        "event_rule_id": "er-123456789012",
        "domain_id": "domain-123456789012"
        }
        response_example: >-
        {
        "event_rule_id": "er-123456789012",
        "order": 2,
        "conditions": [
        {
        "key": "title",
        "value": "ELB",
        "operator": "contain"
        }
        ],
        "conditions_policy": "ALL",
        "actions": {
        "change_assignee": "user1@email.com",
        "change_urgency": "LOW",
        "change_project": "project-123456789012",
        "add_additional_info": {},
        "no_notification": true
        },
        "options": {},
        "scope": "PROJECT",
        "project_id": "project-123456789012",
        "tags": {},
        "domain_id": "domain-123456789012",
        "created_at": "2022-01-01T06:12:30.226Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        desc: Gets a list of all EventRules. You can use a query to get a filtered list of EventRules. For example, you can adjust the scope of the list to a certain Project or Domain.
        request_example: >-
        {
        "project_id": "project-123456789012",
        "domain_id": "domain-123456789012"
        }
        response_example: >-
        {
        "results": [
        {
        "event_rule_id": "er-123456789012",
        "order": 1,
        "conditions": [
        {
        "key": "title",
        "value": "AWS",
        "operator": "contain"
        }
        ],
        "conditions_policy": "ALL",
        "actions": {
        "change_assignee": "user2@email.com",
        "change_urgency": "HIGH",
        "add_additional_info": {},
        "no_notification": true
        },
        "options": {},
        "scope": "PROJECT",
        "project_id": "project-123456789012",
        "tags": {},
        "domain_id": "domain-123456789012",
        "created_at": "2022-01-01T06:33:58.388Z"
        },
        {
        "event_rule_id": "er-123456789012",
        "order": 2,
        "conditions": [
        {
        "key": "title",
        "value": "ELB",
        "operator": "contain"
        }
        ],
        "conditions_policy": "ALL",
        "actions": {
        "change_assignee": "user1@email.com",
        "change_urgency": "LOW",
        "change_project": "project-123456789012",
        "add_additional_info": {},
        "no_notification": true
        },
        "options": {},
        "scope": "PROJECT",
        "project_id": "project-123456789012",
        "tags": {},
        "domain_id": "domain-123456789012",
        "created_at": "2022-01-01T06:12:30.226Z"
        }
        ],
        "total_count": 2
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_EventRuleServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_event__rule__pb2.CreateEventRuleRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_event__rule__pb2.EventRuleInfo.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_event__rule__pb2.UpdateEventRuleRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_event__rule__pb2.EventRuleInfo.SerializeToString,
            ),
            'change_order': grpc.unary_unary_rpc_method_handler(
                    servicer.change_order,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_event__rule__pb2.ChangeEventRuleOrderRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_event__rule__pb2.EventRuleInfo.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_event__rule__pb2.EventRuleRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_event__rule__pb2.GetEventRuleRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_event__rule__pb2.EventRuleInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_event__rule__pb2.EventRuleQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_event__rule__pb2.EventRulesInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_event__rule__pb2.EventRuleStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.monitoring.v1.EventRule', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class EventRule(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.EventRule/create',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_event__rule__pb2.CreateEventRuleRequest.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_event__rule__pb2.EventRuleInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.EventRule/update',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_event__rule__pb2.UpdateEventRuleRequest.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_event__rule__pb2.EventRuleInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def change_order(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.EventRule/change_order',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_event__rule__pb2.ChangeEventRuleOrderRequest.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_event__rule__pb2.EventRuleInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.EventRule/delete',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_event__rule__pb2.EventRuleRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.EventRule/get',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_event__rule__pb2.GetEventRuleRequest.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_event__rule__pb2.EventRuleInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.EventRule/list',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_event__rule__pb2.EventRuleQuery.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_event__rule__pb2.EventRulesInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.EventRule/stat',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_event__rule__pb2.EventRuleStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.cost_analysis.v1 import job_pb2 as spaceone_dot_api_dot_cost__analysis_dot_v1_dot_job__pb2


class JobStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.cancel = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.Job/cancel',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_job__pb2.JobRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_job__pb2.JobInfo.FromString,
                )
        self.get = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.Job/get',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_job__pb2.GetJobRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_job__pb2.JobInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.Job/list',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_job__pb2.JobQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_job__pb2.JobsInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.Job/stat',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_job__pb2.JobStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class JobServicer(object):
    """Missing associated documentation comment in .proto file."""

    def cancel(self, request, context):
        """
        desc: Cancels a specific Job. You can manually cease a Job in run with this method.
        request_example: >-
        {
        "job_id": "job-07994c7c9021"
        }
        response_example: >-
        {
        "job_id": "job-07994c7c9021",
        "status": "CANCELED",
        "options": {
        "no_preload_cache": false,
        "start": "2021-01-01T00:00:00Z"
        },
        "total_tasks": 2,
        "remained_tasks": 2,
        "data_source_id": "ds-fcba92ca73b1",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-04-02T09:17:44.031Z",
        "updated_at": "2022-04-02T09:19:47.715Z",
        "finished_at": "2022-04-02T09:19:47.715Z",
        "changed": [
        {
        "start": "2021-01-01T00:00:00.000Z"
        }
        ]
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        desc: Gets a specific Job. Prints detailed information about the Job, including the plugin used, operation time, and `status`.
        request_example: >-
        {
        "job_id": "job-85cf2c385252"
        }
        response_example: >-
        {
        "job_id": "job-85cf2c385252",
        "status": "SUCCESS",
        "options": {
        "no_preload_cache": false,
        "start": null
        },
        "total_tasks": 1,
        "data_source_id": "ds-c96609f5afeb",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-07-17T16:00:08.254Z",
        "updated_at": "2022-07-17T16:01:30.637Z",
        "finished_at": "2022-07-17T16:01:30.637Z",
        "changed": [
        {
        "start": "2022-07-01T00:00:00.000Z"
        }
        ]
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        desc: Gets a list of all Jobs. You can use a query to get a filtered list of Jobs.
        request_example: >-
        {
        "query": {}
        }
        response_example: >-
        {
        "results": [
        {
        "job_id": "job-85cf2c385252",
        "status": "SUCCESS",
        "options": {
        "start": null,
        "no_preload_cache": false
        },
        "total_tasks": 1,
        "data_source_id": "ds-c96609f5afeb",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-07-17T16:00:08.254Z",
        "updated_at": "2022-07-17T16:01:30.637Z",
        "finished_at": "2022-07-17T16:01:30.637Z",
        "changed": [
        {
        "start": "2022-07-01T00:00:00.000Z"
        }
        ]
        },
        {
        "job_id": "job-6b6765f757a9",
        "status": "SUCCESS",
        "options": {
        "start": null,
        "no_preload_cache": false
        },
        "total_tasks": 2,
        "data_source_id": "ds-fcba92ca73b1",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-07-17T16:00:05.077Z",
        "updated_at": "2022-07-17T16:01:28.206Z",
        "finished_at": "2022-07-17T16:01:28.206Z",
        "changed": [
        {
        "start": "2022-07-01T00:00:00.000Z"
        }
        ]
        }
        ],
        "total_count": 372
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_JobServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'cancel': grpc.unary_unary_rpc_method_handler(
                    servicer.cancel,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_job__pb2.JobRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_job__pb2.JobInfo.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_job__pb2.GetJobRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_job__pb2.JobInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_job__pb2.JobQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_job__pb2.JobsInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_job__pb2.JobStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.cost_analysis.v1.Job', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Job(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def cancel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.Job/cancel',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_job__pb2.JobRequest.SerializeToString,
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_job__pb2.JobInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.Job/get',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_job__pb2.GetJobRequest.SerializeToString,
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_job__pb2.JobInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.Job/list',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_job__pb2.JobQuery.SerializeToString,
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_job__pb2.JobsInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.Job/stat',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_job__pb2.JobStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/cost_analysis/v1/exchange_rate.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1spaceone/api/cost_analysis/v1/exchange_rate.proto\x12\x1dspaceone.api.cost_analysis.v1\x1a\x1cgoogle/api/annotations.proto\"K\n\x16SetExchangeRateRequest\x12\x10\n\x08\x63urrency\x18\x01 \x01(\t\x12\x0c\n\x04rate\x18\x02 \x01(\x02\x12\x11\n\tdomain_id\x18\x0c \x01(\t\":\n\x13\x45xchangeRateRequest\x12\x10\n\x08\x63urrency\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"&\n\x11\x45xchangeRateQuery\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"\xcd\x01\n\x10\x45xchangeRateInfo\x12\x10\n\x08\x63urrency\x18\x01 \x01(\t\x12\x0c\n\x04rate\x18\x02 \x01(\x02\x12\x44\n\x05state\x18\x03 \x01(\x0e\x32\x35.spaceone.api.cost_analysis.v1.ExchangeRateInfo.State\x12\x12\n\nis_default\x18\x04 \x01(\x08\x12\x11\n\tdomain_id\x18\x0b \x01(\t\",\n\x05State\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"j\n\x11\x45xchangeRatesInfo\x12@\n\x07results\x18\x01 \x03(\x0b\x32/.spaceone.api.cost_analysis.v1.ExchangeRateInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\x32\x9a\x08\n\x0c\x45xchangeRate\x12\xa5\x01\n\x03set\x12\x35.spaceone.api.cost_analysis.v1.SetExchangeRateRequest\x1a/.spaceone.api.cost_analysis.v1.ExchangeRateInfo\"6\x82\xd3\xe4\x93\x02\x30\"./cost-analysis/v1/exchange-rate/{currency}/set\x12\xa6\x01\n\x05reset\x12\x32.spaceone.api.cost_analysis.v1.ExchangeRateRequest\x1a/.spaceone.api.cost_analysis.v1.ExchangeRateInfo\"8\x82\xd3\xe4\x93\x02\x32\"0/cost-analysis/v1/exchange-rate/{currency}/reset\x12\xa8\x01\n\x06\x65nable\x12\x32.spaceone.api.cost_analysis.v1.ExchangeRateRequest\x1a/.spaceone.api.cost_analysis.v1.ExchangeRateInfo\"9\x82\xd3\xe4\x93\x02\x33\"1/cost-analysis/v1/exchange-rate/{currency}/enable\x12\xaa\x01\n\x07\x64isable\x12\x32.spaceone.api.cost_analysis.v1.ExchangeRateRequest\x1a/.spaceone.api.cost_analysis.v1.ExchangeRateInfo\":\x82\xd3\xe4\x93\x02\x34\"2/cost-analysis/v1/exchange-rate/{currency}/disable\x12\x9e\x01\n\x03get\x12\x32.spaceone.api.cost_analysis.v1.ExchangeRateRequest\x1a/.spaceone.api.cost_analysis.v1.ExchangeRateInfo\"2\x82\xd3\xe4\x93\x02,\x12*/cost-analysis/v1/exchange-rate/{currency}\x12\xbf\x01\n\x04list\x12\x30.spaceone.api.cost_analysis.v1.ExchangeRateQuery\x1a\x30.spaceone.api.cost_analysis.v1.ExchangeRatesInfo\"S\x82\xd3\xe4\x93\x02M\x12 /cost-analysis/v1/exchange-ratesZ)\"\'/cost-analysis/v1/exchange-rates/searchb\x06proto3')



_SETEXCHANGERATEREQUEST = DESCRIPTOR.message_types_by_name['SetExchangeRateRequest']
_EXCHANGERATEREQUEST = DESCRIPTOR.message_types_by_name['ExchangeRateRequest']
_EXCHANGERATEQUERY = DESCRIPTOR.message_types_by_name['ExchangeRateQuery']
_EXCHANGERATEINFO = DESCRIPTOR.message_types_by_name['ExchangeRateInfo']
_EXCHANGERATESINFO = DESCRIPTOR.message_types_by_name['ExchangeRatesInfo']
_EXCHANGERATEINFO_STATE = _EXCHANGERATEINFO.enum_types_by_name['State']
SetExchangeRateRequest = _reflection.GeneratedProtocolMessageType('SetExchangeRateRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETEXCHANGERATEREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.exchange_rate_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.SetExchangeRateRequest)
  })
_sym_db.RegisterMessage(SetExchangeRateRequest)

ExchangeRateRequest = _reflection.GeneratedProtocolMessageType('ExchangeRateRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXCHANGERATEREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.exchange_rate_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.ExchangeRateRequest)
  })
_sym_db.RegisterMessage(ExchangeRateRequest)

ExchangeRateQuery = _reflection.GeneratedProtocolMessageType('ExchangeRateQuery', (_message.Message,), {
  'DESCRIPTOR' : _EXCHANGERATEQUERY,
  '__module__' : 'spaceone.api.cost_analysis.v1.exchange_rate_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.ExchangeRateQuery)
  })
_sym_db.RegisterMessage(ExchangeRateQuery)

ExchangeRateInfo = _reflection.GeneratedProtocolMessageType('ExchangeRateInfo', (_message.Message,), {
  'DESCRIPTOR' : _EXCHANGERATEINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.exchange_rate_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.ExchangeRateInfo)
  })
_sym_db.RegisterMessage(ExchangeRateInfo)

ExchangeRatesInfo = _reflection.GeneratedProtocolMessageType('ExchangeRatesInfo', (_message.Message,), {
  'DESCRIPTOR' : _EXCHANGERATESINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.exchange_rate_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.ExchangeRatesInfo)
  })
_sym_db.RegisterMessage(ExchangeRatesInfo)

_EXCHANGERATE = DESCRIPTOR.services_by_name['ExchangeRate']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _EXCHANGERATE.methods_by_name['set']._options = None
  _EXCHANGERATE.methods_by_name['set']._serialized_options = b'\202\323\344\223\0020\"./cost-analysis/v1/exchange-rate/{currency}/set'
  _EXCHANGERATE.methods_by_name['reset']._options = None
  _EXCHANGERATE.methods_by_name['reset']._serialized_options = b'\202\323\344\223\0022\"0/cost-analysis/v1/exchange-rate/{currency}/reset'
  _EXCHANGERATE.methods_by_name['enable']._options = None
  _EXCHANGERATE.methods_by_name['enable']._serialized_options = b'\202\323\344\223\0023\"1/cost-analysis/v1/exchange-rate/{currency}/enable'
  _EXCHANGERATE.methods_by_name['disable']._options = None
  _EXCHANGERATE.methods_by_name['disable']._serialized_options = b'\202\323\344\223\0024\"2/cost-analysis/v1/exchange-rate/{currency}/disable'
  _EXCHANGERATE.methods_by_name['get']._options = None
  _EXCHANGERATE.methods_by_name['get']._serialized_options = b'\202\323\344\223\002,\022*/cost-analysis/v1/exchange-rate/{currency}'
  _EXCHANGERATE.methods_by_name['list']._options = None
  _EXCHANGERATE.methods_by_name['list']._serialized_options = b'\202\323\344\223\002M\022 /cost-analysis/v1/exchange-ratesZ)\"\'/cost-analysis/v1/exchange-rates/search'
  _SETEXCHANGERATEREQUEST._serialized_start=114
  _SETEXCHANGERATEREQUEST._serialized_end=189
  _EXCHANGERATEREQUEST._serialized_start=191
  _EXCHANGERATEREQUEST._serialized_end=249
  _EXCHANGERATEQUERY._serialized_start=251
  _EXCHANGERATEQUERY._serialized_end=289
  _EXCHANGERATEINFO._serialized_start=292
  _EXCHANGERATEINFO._serialized_end=497
  _EXCHANGERATEINFO_STATE._serialized_start=453
  _EXCHANGERATEINFO_STATE._serialized_end=497
  _EXCHANGERATESINFO._serialized_start=499
  _EXCHANGERATESINFO._serialized_end=605
  _EXCHANGERATE._serialized_start=608
  _EXCHANGERATE._serialized_end=1658
# @@protoc_insertion_point(module_scope)
